@@ -4,21 +4,23 @@ import pickle
 import threading
 import traceback
 from .utils import *
-from omnitools import encryptedsocket_function, p, utf8d, dt2yyyymmddhhmmss
+from omnitools import encryptedsocket_function, p, utf8d, dt2yyyymmddhhmmss, debug_info
 
 
 __ALL__ = ["SS"]
 
 
 class SS:
-    def __init__(self, functions: encryptedsocket_function = None,
-                 host: str = "127.199.71.10", port: int = 39291,
-                 silent: bool = False) -> None:
+    def __init__(
+            self, functions: encryptedsocket_function = None,
+            host: str = "127.199.71.10", port: int = 39291,
+            silent: bool = False, backlog: int = 5
+    ):
         self.terminate = False
         self.silent = silent
         self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.s.bind((host, int(port)))
-        self.s.listen(5)
+        self.s.listen(backlog)
         self.__key = {}
         self.functions = functions or {}
 
@@ -41,14 +43,14 @@ class SS:
                     else:
                         raise Exception("request command '{}' is not in socket functions".format(request["command"]))
                 except:
-                    response = traceback.format_exc()
+                    response = debug_info()[0]
                 try:
                     response = json.dumps(response).encode()
                 except TypeError:
                     response = pickle.dumps(response)
                 conn.sendall(struct.pack('>I', len(response))+response)
-        except Exception as e:
-            p(e)
+        except:
+            p(debug_info()[0])
         finally:
             conn.close()
             if not self.silent:
